/********************************************************************************
** Form generated from reading UI file 'dialogconversionstatus.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGCONVERSIONSTATUS_H
#define UI_DIALOGCONVERSIONSTATUS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogConversionStatus
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label_4;
    QTreeWidget *treeWidget;
    QFrame *line;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label;
    QLabel *labelTotal;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QLabel *labelOk;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    QLabel *labelKo;
    QSpacerItem *horizontalSpacer_4;
    QProgressBar *progressBar;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout;
    QPushButton *pushOpen;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushAbort;
    QPushButton *pushClose;

    void setupUi(QDialog *DialogConversionStatus)
    {
        if (DialogConversionStatus->objectName().isEmpty())
            DialogConversionStatus->setObjectName("DialogConversionStatus");
        DialogConversionStatus->resize(610, 341);
        verticalLayout_2 = new QVBoxLayout(DialogConversionStatus);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_4 = new QLabel(DialogConversionStatus);
        label_4->setObjectName("label_4");

        verticalLayout_2->addWidget(label_4);

        treeWidget = new QTreeWidget(DialogConversionStatus);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        treeWidget->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        treeWidget->setAlternatingRowColors(true);
        treeWidget->setSelectionMode(QAbstractItemView::NoSelection);
        treeWidget->setTextElideMode(Qt::ElideNone);
        treeWidget->setHorizontalScrollMode(QAbstractItemView::ScrollPerItem);
        treeWidget->setRootIsDecorated(false);
        treeWidget->setUniformRowHeights(false);
        treeWidget->setWordWrap(false);
        treeWidget->header()->setDefaultSectionSize(100);
        treeWidget->header()->setStretchLastSection(false);

        verticalLayout_2->addWidget(treeWidget);

        line = new QFrame(DialogConversionStatus);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label = new QLabel(DialogConversionStatus);
        label->setObjectName("label");

        horizontalLayout_4->addWidget(label);

        labelTotal = new QLabel(DialogConversionStatus);
        labelTotal->setObjectName("labelTotal");

        horizontalLayout_4->addWidget(labelTotal);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(DialogConversionStatus);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        labelOk = new QLabel(DialogConversionStatus);
        labelOk->setObjectName("labelOk");

        horizontalLayout_2->addWidget(labelOk);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_3 = new QLabel(DialogConversionStatus);
        label_3->setObjectName("label_3");

        horizontalLayout_3->addWidget(label_3);

        labelKo = new QLabel(DialogConversionStatus);
        labelKo->setObjectName("labelKo");

        horizontalLayout_3->addWidget(labelKo);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_3);


        verticalLayout_2->addLayout(verticalLayout);

        progressBar = new QProgressBar(DialogConversionStatus);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(24);

        verticalLayout_2->addWidget(progressBar);

        line_2 = new QFrame(DialogConversionStatus);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        pushOpen = new QPushButton(DialogConversionStatus);
        pushOpen->setObjectName("pushOpen");

        horizontalLayout->addWidget(pushOpen);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushAbort = new QPushButton(DialogConversionStatus);
        pushAbort->setObjectName("pushAbort");

        horizontalLayout->addWidget(pushAbort);

        pushClose = new QPushButton(DialogConversionStatus);
        pushClose->setObjectName("pushClose");

        horizontalLayout->addWidget(pushClose);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(DialogConversionStatus);

        QMetaObject::connectSlotsByName(DialogConversionStatus);
    } // setupUi

    void retranslateUi(QDialog *DialogConversionStatus)
    {
        DialogConversionStatus->setWindowTitle(QCoreApplication::translate("DialogConversionStatus", "Status...", nullptr));
        label_4->setText(QCoreApplication::translate("DialogConversionStatus", "Conversion Status", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("DialogConversionStatus", "Status:", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("DialogConversionStatus", "Image:", nullptr));
        label->setText(QCoreApplication::translate("DialogConversionStatus", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Total:</span></p></body></html>", nullptr));
        labelTotal->setText(QCoreApplication::translate("DialogConversionStatus", "0", nullptr));
        label_2->setText(QCoreApplication::translate("DialogConversionStatus", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Converted:</span></p></body></html>", nullptr));
        labelOk->setText(QCoreApplication::translate("DialogConversionStatus", "0", nullptr));
        label_3->setText(QCoreApplication::translate("DialogConversionStatus", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Errors:</span></p></body></html>", nullptr));
        labelKo->setText(QCoreApplication::translate("DialogConversionStatus", "0", nullptr));
        pushOpen->setText(QCoreApplication::translate("DialogConversionStatus", "Open destination ", nullptr));
        pushAbort->setText(QCoreApplication::translate("DialogConversionStatus", "Stop", nullptr));
        pushClose->setText(QCoreApplication::translate("DialogConversionStatus", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogConversionStatus: public Ui_DialogConversionStatus {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGCONVERSIONSTATUS_H
