/********************************************************************************
** Form generated from reading UI file 'dialoginfo.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGINFO_H
#define UI_DIALOGINFO_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DialogInfo
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_5;
    QLabel *labelTitle;
    QLabel *label_3;
    QLabel *labelMagickVersion;
    QLabel *labelQtVersion;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QLabel *label;
    QLabel *label_6;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_8;
    QLabel *label_9;
    QLabel *label_10;
    QLabel *label_11;
    QLabel *label_12;
    QLabel *label_13;
    QLabel *label_14;
    QLabel *label_4;
    QLabel *label_16;
    QLabel *label_17;
    QLabel *label_15;
    QLabel *label_19;
    QLabel *label_20;
    QLabel *label_21;
    QLabel *label_22;
    QVBoxLayout *verticalLayout;
    QLabel *label_18;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *pushDonatePayPal;
    QSpacerItem *horizontalSpacer_5;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    QPushButton *pushFacebook;
    QSpacerItem *horizontalSpacer_3;
    QFrame *line;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushClose;

    void setupUi(QDialog *DialogInfo)
    {
        if (DialogInfo->objectName().isEmpty())
            DialogInfo->setObjectName("DialogInfo");
        DialogInfo->resize(526, 670);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DialogInfo->sizePolicy().hasHeightForWidth());
        DialogInfo->setSizePolicy(sizePolicy);
        DialogInfo->setMinimumSize(QSize(0, 0));
        verticalLayout_2 = new QVBoxLayout(DialogInfo);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_5 = new QLabel(DialogInfo);
        label_5->setObjectName("label_5");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy1);
        label_5->setPixmap(QPixmap(QString::fromUtf8(":/Images/res/icon.png")));

        horizontalLayout->addWidget(label_5);

        labelTitle = new QLabel(DialogInfo);
        labelTitle->setObjectName("labelTitle");

        horizontalLayout->addWidget(labelTitle);


        verticalLayout_2->addLayout(horizontalLayout);

        label_3 = new QLabel(DialogInfo);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout_2->addWidget(label_3);

        labelMagickVersion = new QLabel(DialogInfo);
        labelMagickVersion->setObjectName("labelMagickVersion");
        labelMagickVersion->setWordWrap(true);
        labelMagickVersion->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(labelMagickVersion);

        labelQtVersion = new QLabel(DialogInfo);
        labelQtVersion->setObjectName("labelQtVersion");
        labelQtVersion->setWordWrap(true);
        labelQtVersion->setOpenExternalLinks(true);

        verticalLayout_2->addWidget(labelQtVersion);

        groupBox = new QGroupBox(DialogInfo);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy2);
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setOpenExternalLinks(true);

        verticalLayout_4->addWidget(label);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        verticalLayout_4->addWidget(label_6);

        scrollArea = new QScrollArea(groupBox);
        scrollArea->setObjectName("scrollArea");
        sizePolicy2.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy2);
        scrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, -229, 882, 372));
        verticalLayout_3 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_8 = new QLabel(scrollAreaWidgetContents);
        label_8->setObjectName("label_8");

        verticalLayout_3->addWidget(label_8);

        label_9 = new QLabel(scrollAreaWidgetContents);
        label_9->setObjectName("label_9");

        verticalLayout_3->addWidget(label_9);

        label_10 = new QLabel(scrollAreaWidgetContents);
        label_10->setObjectName("label_10");

        verticalLayout_3->addWidget(label_10);

        label_11 = new QLabel(scrollAreaWidgetContents);
        label_11->setObjectName("label_11");
        label_11->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_11);

        label_12 = new QLabel(scrollAreaWidgetContents);
        label_12->setObjectName("label_12");

        verticalLayout_3->addWidget(label_12);

        label_13 = new QLabel(scrollAreaWidgetContents);
        label_13->setObjectName("label_13");

        verticalLayout_3->addWidget(label_13);

        label_14 = new QLabel(scrollAreaWidgetContents);
        label_14->setObjectName("label_14");
        label_14->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_14);

        label_4 = new QLabel(scrollAreaWidgetContents);
        label_4->setObjectName("label_4");
        label_4->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_4);

        label_16 = new QLabel(scrollAreaWidgetContents);
        label_16->setObjectName("label_16");
        label_16->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_16);

        label_17 = new QLabel(scrollAreaWidgetContents);
        label_17->setObjectName("label_17");

        verticalLayout_3->addWidget(label_17);

        label_15 = new QLabel(scrollAreaWidgetContents);
        label_15->setObjectName("label_15");

        verticalLayout_3->addWidget(label_15);

        label_19 = new QLabel(scrollAreaWidgetContents);
        label_19->setObjectName("label_19");

        verticalLayout_3->addWidget(label_19);

        label_20 = new QLabel(scrollAreaWidgetContents);
        label_20->setObjectName("label_20");

        verticalLayout_3->addWidget(label_20);

        label_21 = new QLabel(scrollAreaWidgetContents);
        label_21->setObjectName("label_21");

        verticalLayout_3->addWidget(label_21);

        label_22 = new QLabel(scrollAreaWidgetContents);
        label_22->setObjectName("label_22");
        label_22->setTextFormat(Qt::TextFormat::RichText);
        label_22->setOpenExternalLinks(true);

        verticalLayout_3->addWidget(label_22);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_4->addWidget(scrollArea);


        verticalLayout_2->addWidget(groupBox);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        label_18 = new QLabel(DialogInfo);
        label_18->setObjectName("label_18");
        label_18->setWordWrap(true);

        verticalLayout->addWidget(label_18);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        pushDonatePayPal = new QPushButton(DialogInfo);
        pushDonatePayPal->setObjectName("pushDonatePayPal");
        pushDonatePayPal->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        pushDonatePayPal->setIconSize(QSize(150, 50));
        pushDonatePayPal->setAutoDefault(false);
        pushDonatePayPal->setFlat(true);

        horizontalLayout_4->addWidget(pushDonatePayPal);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        verticalLayout->addLayout(horizontalLayout_4);


        verticalLayout_2->addLayout(verticalLayout);

        line_2 = new QFrame(DialogInfo);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line_2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_7 = new QLabel(DialogInfo);
        label_7->setObjectName("label_7");

        horizontalLayout_3->addWidget(label_7);

        pushFacebook = new QPushButton(DialogInfo);
        pushFacebook->setObjectName("pushFacebook");
        pushFacebook->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/Images/res/facebook-icon.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushFacebook->setIcon(icon);
        pushFacebook->setIconSize(QSize(32, 32));
        pushFacebook->setAutoDefault(false);
        pushFacebook->setFlat(true);

        horizontalLayout_3->addWidget(pushFacebook);


        horizontalLayout_5->addLayout(horizontalLayout_3);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        verticalLayout_2->addLayout(horizontalLayout_5);

        line = new QFrame(DialogInfo);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        label_2 = new QLabel(DialogInfo);
        label_2->setObjectName("label_2");
        label_2->setText(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><meta charset=\"utf-8\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"hr { height: 1px; border-width: 0; }\n"
"li.unchecked::marker { content: \"\\2610\"; }\n"
"li.checked::marker { content: \"\\2612\"; }\n"
"</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2';\">(c) 2009 - 2026 Francesco Mondello GNU - GPL v.3</span></p></body></html>"));

        verticalLayout_2->addWidget(label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pushClose = new QPushButton(DialogInfo);
        pushClose->setObjectName("pushClose");

        horizontalLayout_2->addWidget(pushClose);


        verticalLayout_2->addLayout(horizontalLayout_2);

        groupBox->raise();
        line->raise();
        label_3->raise();
        label_2->raise();
        line_2->raise();
        labelMagickVersion->raise();
        labelQtVersion->raise();

        retranslateUi(DialogInfo);

        QMetaObject::connectSlotsByName(DialogInfo);
    } // setupUi

    void retranslateUi(QDialog *DialogInfo)
    {
        DialogInfo->setWindowTitle(QCoreApplication::translate("DialogInfo", "About Converseen...", nullptr));
        label_5->setText(QString());
        labelTitle->setText(QCoreApplication::translate("DialogInfo", "-", nullptr));
        label_3->setText(QCoreApplication::translate("DialogInfo", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'MS Shell Dlg 2'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt;\">Converseen is an image batch conversion tool. You can resize and convert images in more than 100 different formats.</span></p></body></html>", nullptr));
        labelMagickVersion->setText(QCoreApplication::translate("DialogInfo", "-", nullptr));
        labelQtVersion->setText(QCoreApplication::translate("DialogInfo", "-", nullptr));
        groupBox->setTitle(QCoreApplication::translate("DialogInfo", "Informations", nullptr));
        label->setText(QCoreApplication::translate("DialogInfo", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt; font-weight:600;\">Author: </span><span style=\" font-size:10pt;\">Francesco Mondello (Faster) - </span><a href=\"https://fasterland.net/\"><span style=\" text-decoration: underline; \">fasterland.net</span></a></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt; font-weight:600;\">Email: </span><a href=\"faster3ck@gmail.com\"><span style=\" font-size:10pt; text-decoration: underline; \">faster3ck@gmail.com</span></a></p>\n"
""
                        "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:10pt; font-weight:600;\">Project Website: </span><a href=\"https://converseen.fasterland.net\"><span style=\" text-decoration: underline; \">converseen.fasterland.net</span></a></p></body></html>", nullptr));
        label_6->setText(QCoreApplication::translate("DialogInfo", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Translators:</span></p></body></html>", nullptr));
        label_8->setText(QCoreApplication::translate("DialogInfo", "<strong>Hungarian translation: </strong>Charles Barcza - <a href=\"mailto:kbarcza@blackpanther.hu\">kbarcza@blackpanther.hu</a>", nullptr));
        label_9->setText(QCoreApplication::translate("DialogInfo", "<strong>Czech translation: </strong>Pavel Fric - <a href=\"mailto:pavelfric@seznam.cz\">pavelfric@seznam.cz</a>", nullptr));
        label_10->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:600;\">French Translation: </span>Adrien DAUGABEL - <a href=\"mailto:adrien.d@mageialinux-online.org\"><span style=\" text-decoration: underline; \">adrien.d@mageialinux-online.org - </span></a>David GEIGER <a href=\"mailto:david.david@mageialinux-online.org\"><span style=\" text-decoration: underline; \">david.david@mageialinux-online.org</span></a></p></body></html>", nullptr));
        label_11->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:600;\">Brazilian Portuguese Translation: </span>Paulo Guzm\303\241n - <a href=\"mailto:white.hat@msn.com\"><span style=\" text-decoration: underline; \">white.hat@msn.com</span></a> -<span style=\" font-weight:600;\"/>M\303\241rcio Moraes - <a href=\"mailto:marciopanto@gmail.com\"><span style=\" text-decoration: underline; \">marciopanto@gmail.com</span></a></p></body></html>", nullptr));
        label_12->setText(QCoreApplication::translate("DialogInfo", "<strong>German Translation: </strong>Marco Nickolai - <a href=\"mailto:nickolai@iad.tu-darmstadt.de\">nickolai@iad.tu-darmstadt.de</a>", nullptr));
        label_13->setText(QCoreApplication::translate("DialogInfo", "<strong>Spanish (Chile) Translation: </strong>Nelson \303\201lvarez S\303\241ez - <a href=\"mailto:alvareznelson@gmail.com\">alvareznelson@gmail.com</a>", nullptr));
        label_14->setText(QCoreApplication::translate("DialogInfo", "<strong>Turkish Translation: </strong>Zeugma - <a href=\"mailto:sunder67@hotmail.com\">sunder67@hotmail.com</a> - Sabri \303\234nal - <a href=\"mailto:yakushabb@gmail.com\">yakushabb@gmail.com</a>", nullptr));
        label_4->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:700;\">Russian Translation: </span><a href=\"https://github.com/alevtina-karashokova\"><span style=\" text-decoration: underline; color:#007af4;\">Alevtina Karashokova</span></a>, Stasik Savorovsky - <a href=\"mailto:stas_stv@mail.ru\"><span style=\" text-decoration: underline; color:#007af4;\">stas_stv@mail.ru</span></a>, Kyrill Detinov - <a href=\"mailto:lazy.kent@opensuse.org\"><span style=\" text-decoration: underline; color:#007af4;\">lazy.kent@opensuse.org</span></a>, ViktorOn - <a href=\"https://github.com/ViktorOn\"><span style=\" text-decoration: underline; color:#007af4;\">ViktorOn</span></a></p></body></html>", nullptr));
        label_16->setText(QCoreApplication::translate("DialogInfo", "<strong>Polish Translation: </strong>Micha\305\202 Olber from OSWorld.pl - <a href=\"mailto:redakcja@osworld.pl\">redakcja@osworld.pl</a>", nullptr));
        label_17->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:600;\">Japanese translation:</span> Xenolith0 - <a href=\"mailto:xenolith0bytetestcomgreen@gmail.com\"><span style=\" text-decoration: underline; \">xenolith0bytetestcomgreen@gmail.com</span></a></p></body></html>", nullptr));
        label_15->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:600;\">Danish translation: </span>Martin Eilsoe - <a href=\"mailto:martin.eilsoe@gmail.com\"><span style=\" text-decoration: underline; \">martin.eilsoe@gmail.com</span></a></p></body></html>", nullptr));
        label_19->setText(QCoreApplication::translate("DialogInfo", "<strong>Ukrainian translation: </strong>AleXKaN - <a href=\"mailto:aws2@india.com\">aws2@india.com</a>", nullptr));
        label_20->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-weight:600;\">Swedish translation: </span>\303\205ke Engelbrektson - <a href=\"mailto:eson@svenskasprakfiler.se\"><span style=\" text-decoration: underline; color:#0057ae;\">eson@svenskasprakfiler.se</span></a></p></body></html>", nullptr));
        label_21->setText(QCoreApplication::translate("DialogInfo", "<strong>Simplified Chinese translation: </strong>myd7349 - <a href=\"mailto:myd7349@gmail.com\">myd7349@gmail.com</a>", nullptr));
        label_22->setText(QCoreApplication::translate("DialogInfo", "<strong>Korean translation: </strong>JungHee Lee - <a href=\"https://github.com/MarongHappy\">MarongHappy (GitHub)</a>", nullptr));
        label_18->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">If you appreciate this work and would like to support the project, you are welcome to donate via PayPal</span></p></body></html>", nullptr));
        pushDonatePayPal->setText(QString());
        label_7->setText(QCoreApplication::translate("DialogInfo", "<html><head/><body><p><span style=\" font-size:11pt; font-weight:600;\">Follow Converseen:</span></p></body></html>", nullptr));
        pushFacebook->setText(QString());
        pushClose->setText(QCoreApplication::translate("DialogInfo", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogInfo: public Ui_DialogInfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGINFO_H
