/********************************************************************************
** Form generated from reading UI file 'dialogshowupdatemsg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGSHOWUPDATEMSG_H
#define UI_DIALOGSHOWUPDATEMSG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogShowUpdateMsg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *labelMsg;
    QSpacerItem *verticalSpacer;
    QCheckBox *checkBoxDisable;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushOk;
    QPushButton *pushCancel;

    void setupUi(QDialog *DialogShowUpdateMsg)
    {
        if (DialogShowUpdateMsg->objectName().isEmpty())
            DialogShowUpdateMsg->setObjectName("DialogShowUpdateMsg");
        DialogShowUpdateMsg->resize(366, 130);
        verticalLayout = new QVBoxLayout(DialogShowUpdateMsg);
        verticalLayout->setObjectName("verticalLayout");
        labelMsg = new QLabel(DialogShowUpdateMsg);
        labelMsg->setObjectName("labelMsg");

        verticalLayout->addWidget(labelMsg);

        verticalSpacer = new QSpacerItem(20, 24, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        checkBoxDisable = new QCheckBox(DialogShowUpdateMsg);
        checkBoxDisable->setObjectName("checkBoxDisable");

        verticalLayout->addWidget(checkBoxDisable);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushOk = new QPushButton(DialogShowUpdateMsg);
        pushOk->setObjectName("pushOk");

        horizontalLayout->addWidget(pushOk);

        pushCancel = new QPushButton(DialogShowUpdateMsg);
        pushCancel->setObjectName("pushCancel");

        horizontalLayout->addWidget(pushCancel);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(DialogShowUpdateMsg);

        QMetaObject::connectSlotsByName(DialogShowUpdateMsg);
    } // setupUi

    void retranslateUi(QDialog *DialogShowUpdateMsg)
    {
        DialogShowUpdateMsg->setWindowTitle(QCoreApplication::translate("DialogShowUpdateMsg", "Dialog", nullptr));
        labelMsg->setText(QCoreApplication::translate("DialogShowUpdateMsg", "TextLabel", nullptr));
        checkBoxDisable->setText(QCoreApplication::translate("DialogShowUpdateMsg", "Don't show again", nullptr));
        pushOk->setText(QCoreApplication::translate("DialogShowUpdateMsg", "Update Now", nullptr));
        pushCancel->setText(QCoreApplication::translate("DialogShowUpdateMsg", "Not Now", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogShowUpdateMsg: public Ui_DialogShowUpdateMsg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGSHOWUPDATEMSG_H
