/********************************************************************************
** Form generated from reading UI file 'dialogmultipageeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGMULTIPAGEEDITOR_H
#define UI_DIALOGMULTIPAGEEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogMultipageEditor
{
public:
    QAction *actionCheck;
    QAction *actionCheckAll;
    QAction *actionUncheck;
    QAction *actionUncheckAll;
    QAction *actionHelp;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *treeWidget;
    QLabel *labelHelpPDF;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushCancel;
    QPushButton *pushOk;

    void setupUi(QDialog *DialogMultipageEditor)
    {
        if (DialogMultipageEditor->objectName().isEmpty())
            DialogMultipageEditor->setObjectName("DialogMultipageEditor");
        DialogMultipageEditor->resize(897, 426);
        actionCheck = new QAction(DialogMultipageEditor);
        actionCheck->setObjectName("actionCheck");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/Images/res/apply.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionCheck->setIcon(icon);
        actionCheckAll = new QAction(DialogMultipageEditor);
        actionCheckAll->setObjectName("actionCheckAll");
        actionCheckAll->setIcon(icon);
        actionUncheck = new QAction(DialogMultipageEditor);
        actionUncheck->setObjectName("actionUncheck");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/Images/res/adept_purge.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionUncheck->setIcon(icon1);
        actionUncheckAll = new QAction(DialogMultipageEditor);
        actionUncheckAll->setObjectName("actionUncheckAll");
        actionUncheckAll->setIcon(icon1);
        actionHelp = new QAction(DialogMultipageEditor);
        actionHelp->setObjectName("actionHelp");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/Images/res/help.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionHelp->setIcon(icon2);
        actionHelp->setMenuRole(QAction::NoRole);
        verticalLayout = new QVBoxLayout(DialogMultipageEditor);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(DialogMultipageEditor);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        treeWidget = new QTreeWidget(DialogMultipageEditor);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("Subpage"));
        treeWidget->setHeaderItem(__qtreewidgetitem);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeWidget->setRootIsDecorated(false);
        treeWidget->header()->setVisible(true);

        verticalLayout->addWidget(treeWidget);

        labelHelpPDF = new QLabel(DialogMultipageEditor);
        labelHelpPDF->setObjectName("labelHelpPDF");
        labelHelpPDF->setOpenExternalLinks(true);
        labelHelpPDF->setTextInteractionFlags(Qt::TextBrowserInteraction);

        verticalLayout->addWidget(labelHelpPDF);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushCancel = new QPushButton(DialogMultipageEditor);
        pushCancel->setObjectName("pushCancel");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/Images/res/cancel.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushCancel->setIcon(icon3);

        horizontalLayout->addWidget(pushCancel);

        pushOk = new QPushButton(DialogMultipageEditor);
        pushOk->setObjectName("pushOk");
        pushOk->setIcon(icon);

        horizontalLayout->addWidget(pushOk);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(DialogMultipageEditor);

        QMetaObject::connectSlotsByName(DialogMultipageEditor);
    } // setupUi

    void retranslateUi(QDialog *DialogMultipageEditor)
    {
        DialogMultipageEditor->setWindowTitle(QCoreApplication::translate("DialogMultipageEditor", "Import multipage document", nullptr));
        actionCheck->setText(QCoreApplication::translate("DialogMultipageEditor", "Check", nullptr));
        actionCheckAll->setText(QCoreApplication::translate("DialogMultipageEditor", "Check all", nullptr));
        actionUncheck->setText(QCoreApplication::translate("DialogMultipageEditor", "Uncheck", nullptr));
        actionUncheckAll->setText(QCoreApplication::translate("DialogMultipageEditor", "Uncheck all", nullptr));
        actionHelp->setText(QCoreApplication::translate("DialogMultipageEditor", "Help", nullptr));
#if QT_CONFIG(tooltip)
        actionHelp->setToolTip(QCoreApplication::translate("DialogMultipageEditor", "Open online help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionHelp->setShortcut(QCoreApplication::translate("DialogMultipageEditor", "F1", nullptr));
#endif // QT_CONFIG(shortcut)
        label->setText(QCoreApplication::translate("DialogMultipageEditor", "Check the pages or subimages you want to import", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(4, QCoreApplication::translate("DialogMultipageEditor", "Depth", nullptr));
        ___qtreewidgetitem->setText(3, QCoreApplication::translate("DialogMultipageEditor", "Density", nullptr));
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("DialogMultipageEditor", "Pixel size", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("DialogMultipageEditor", "Page", nullptr));
        labelHelpPDF->setText(QCoreApplication::translate("DialogMultipageEditor", "<html><head/><body><p><a href=\"https://converseen.fasterland.net/converseen-can-convert-pdf-as-image-files/\"><span style=\" text-decoration: underline; color:#007af4;\">How to enable the PDF conversion?</span></a></p></body></html>", nullptr));
        pushCancel->setText(QCoreApplication::translate("DialogMultipageEditor", "Cancel", nullptr));
        pushOk->setText(QCoreApplication::translate("DialogMultipageEditor", "Import", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogMultipageEditor: public Ui_DialogMultipageEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGMULTIPAGEEDITOR_H
