/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "src/mylabelpreviewer.h"
#include "src/pixtreewidget.h"
#include "src/pushcolorchooser.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionOpenFiles;
    QAction *actionAddFiles;
    QAction *actionRemoveItems;
    QAction *actionRemoveAllItems;
    QAction *actionCheckItems;
    QAction *actionCheckAllItems;
    QAction *actionConvert;
    QAction *actionShowOptions;
    QAction *actionClose;
    QAction *actionUncheckAllItems;
    QAction *actionUncheckItems;
    QAction *actionInfo;
    QAction *actionDonatePaypal;
    QAction *actionReportBug;
    QAction *actionImportPDFFile;
    QAction *actionImportWindowsIconIco;
    QAction *actionCheckForUpdates;
    QAction *actionAddDirectory;
    QAction *actionHelp;
    QAction *actionInvertCheckedItems;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout_20;
    PixTreeWidget *treeWidget;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QComboBox *comboWFormats;
    QPushButton *btnFormatOptions;
    QFrame *line_6;
    QHBoxLayout *horizontalLayout_18;
    QSpacerItem *horizontalSpacer_8;
    QCheckBox *checkNoTransp;
    PushColorChooser *pushColor;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_9;
    QVBoxLayout *verticalLayout_4;
    QLabel *label;
    QHBoxLayout *horizontalLayout_8;
    QLineEdit *lineDirectory;
    QToolButton *bntSelDir;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *checkSameDir;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_3;
    QFrame *line;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *checkRename;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *radioPrefixSuffix;
    QRadioButton *radioProgressive;
    QHBoxLayout *horizontalLayout_14;
    QLineEdit *lineRename;
    QLabel *labeStartWith;
    QSpinBox *spinProgressiveRen;
    QFrame *line_5;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_21;
    QHBoxLayout *horizontalLayout_17;
    QRadioButton *radioOverwriteAsk;
    QSpacerItem *horizontalSpacer;
    QRadioButton *radioSkipExisting;
    QSpacerItem *horizontalSpacer_6;
    QRadioButton *radioOverwriteExisting;
    QMenuBar *menubar;
    QMenu *menu_File;
    QMenu *menu_Edit;
    QMenu *menu_Actions;
    QMenu *menu_About;
    QStatusBar *statusbar;
    QDockWidget *dockWidget;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_7;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_12;
    QLabel *label_7;
    QFrame *line_3;
    QFrame *frame;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer_4;
    myLabelPreviewer *labelPreview;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *checkShowPreview;
    QFrame *line_2;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout_14;
    QVBoxLayout *verticalLayout_13;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_3;
    QLabel *labelType;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_9;
    QLabel *labelFileSize;
    QHBoxLayout *horizontalLayout_13;
    QLabel *label_10;
    QLabel *label_ImageSize;
    QHBoxLayout *horizontalLayout_16;
    QLabel *label_11;
    QLabel *label_ImageResolution;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *groupDimensions;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_5;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_4;
    QLabel *label_5;
    QVBoxLayout *verticalLayout_3;
    QDoubleSpinBox *spin_geoWidth;
    QDoubleSpinBox *spin_geoHeight;
    QVBoxLayout *verticalLayout_5;
    QComboBox *comboResizeValues;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *pushReset;
    QPushButton *pushLinkAspect;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelPixelGeometry;
    QHBoxLayout *horizontalLayout_20;
    QCheckBox *checkRelative;
    QLabel *labelAspectRatioHelp;
    QSpacerItem *horizontalSpacer_7;
    QGroupBox *groupResolution;
    QHBoxLayout *horizontalLayout_15;
    QHBoxLayout *horizontalLayout_6;
    QVBoxLayout *verticalLayout_9;
    QLabel *label_6;
    QLabel *label_8;
    QVBoxLayout *verticalLayout_10;
    QDoubleSpinBox *spin_resX;
    QDoubleSpinBox *spin_resY;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_15;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_18;
    QLabel *label_12;
    QHBoxLayout *horizontalLayout_19;
    QRadioButton *radioRotNo;
    QVBoxLayout *verticalLayout_17;
    QHBoxLayout *horizontalLayout_10;
    QRadioButton *radioRotPos90;
    QRadioButton *radioRotNeg90;
    QRadioButton *radioRot180;
    QFrame *line_4;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *radioFlipNo;
    QVBoxLayout *verticalLayout_16;
    QRadioButton *radioFlipH;
    QRadioButton *radioFlipV;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;
    QToolBar *toolBar;
    QButtonGroup *buttonGroup_2;
    QButtonGroup *buttonGroup;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(1482, 888);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MainWindow->sizePolicy().hasHeightForWidth());
        MainWindow->setSizePolicy(sizePolicy);
        MainWindow->setMinimumSize(QSize(0, 0));
        MainWindow->setBaseSize(QSize(1080, 850));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/Images/res/icon.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        MainWindow->setWindowIcon(icon);
        actionOpenFiles = new QAction(MainWindow);
        actionOpenFiles->setObjectName("actionOpenFiles");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/Images/res/folder_documents.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionOpenFiles->setIcon(icon1);
        actionAddFiles = new QAction(MainWindow);
        actionAddFiles->setObjectName("actionAddFiles");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/Images/res/add.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionAddFiles->setIcon(icon2);
        actionRemoveItems = new QAction(MainWindow);
        actionRemoveItems->setObjectName("actionRemoveItems");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/Images/res/adept_purge.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionRemoveItems->setIcon(icon3);
        actionRemoveAllItems = new QAction(MainWindow);
        actionRemoveAllItems->setObjectName("actionRemoveAllItems");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/Images/res/cancel.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionRemoveAllItems->setIcon(icon4);
        actionCheckItems = new QAction(MainWindow);
        actionCheckItems->setObjectName("actionCheckItems");
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/Images/res/apply.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionCheckItems->setIcon(icon5);
        actionCheckAllItems = new QAction(MainWindow);
        actionCheckAllItems->setObjectName("actionCheckAllItems");
        actionCheckAllItems->setIcon(icon5);
        actionConvert = new QAction(MainWindow);
        actionConvert->setObjectName("actionConvert");
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/Images/res/exec.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionConvert->setIcon(icon6);
        actionShowOptions = new QAction(MainWindow);
        actionShowOptions->setObjectName("actionShowOptions");
        actionClose = new QAction(MainWindow);
        actionClose->setObjectName("actionClose");
        actionUncheckAllItems = new QAction(MainWindow);
        actionUncheckAllItems->setObjectName("actionUncheckAllItems");
        actionUncheckItems = new QAction(MainWindow);
        actionUncheckItems->setObjectName("actionUncheckItems");
        actionInfo = new QAction(MainWindow);
        actionInfo->setObjectName("actionInfo");
        actionDonatePaypal = new QAction(MainWindow);
        actionDonatePaypal->setObjectName("actionDonatePaypal");
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/Images/res/heart.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionDonatePaypal->setIcon(icon7);
        actionReportBug = new QAction(MainWindow);
        actionReportBug->setObjectName("actionReportBug");
        actionImportPDFFile = new QAction(MainWindow);
        actionImportPDFFile->setObjectName("actionImportPDFFile");
        actionImportWindowsIconIco = new QAction(MainWindow);
        actionImportWindowsIconIco->setObjectName("actionImportWindowsIconIco");
        actionCheckForUpdates = new QAction(MainWindow);
        actionCheckForUpdates->setObjectName("actionCheckForUpdates");
        actionAddDirectory = new QAction(MainWindow);
        actionAddDirectory->setObjectName("actionAddDirectory");
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/Images/res/add_folder.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionAddDirectory->setIcon(icon8);
        actionHelp = new QAction(MainWindow);
        actionHelp->setObjectName("actionHelp");
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/Images/res/help.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionHelp->setIcon(icon9);
        actionInvertCheckedItems = new QAction(MainWindow);
        actionInvertCheckedItems->setObjectName("actionInvertCheckedItems");
        actionInvertCheckedItems->setMenuRole(QAction::MenuRole::NoRole);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName("centralwidget");
        verticalLayout_20 = new QVBoxLayout(centralwidget);
        verticalLayout_20->setObjectName("verticalLayout_20");
        treeWidget = new PixTreeWidget(centralwidget);
        treeWidget->setObjectName("treeWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(treeWidget->sizePolicy().hasHeightForWidth());
        treeWidget->setSizePolicy(sizePolicy1);
        treeWidget->setBaseSize(QSize(720, 680));

        verticalLayout_20->addWidget(treeWidget);

        groupBox_3 = new QGroupBox(centralwidget);
        groupBox_3->setObjectName("groupBox_3");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy2);
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        comboWFormats = new QComboBox(groupBox_3);
        comboWFormats->setObjectName("comboWFormats");
        sizePolicy2.setHeightForWidth(comboWFormats->sizePolicy().hasHeightForWidth());
        comboWFormats->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(comboWFormats);

        btnFormatOptions = new QPushButton(groupBox_3);
        btnFormatOptions->setObjectName("btnFormatOptions");

        horizontalLayout->addWidget(btnFormatOptions);


        verticalLayout->addLayout(horizontalLayout);

        line_6 = new QFrame(groupBox_3);
        line_6->setObjectName("line_6");
        line_6->setFrameShape(QFrame::Shape::HLine);
        line_6->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line_6);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_8);

        checkNoTransp = new QCheckBox(groupBox_3);
        checkNoTransp->setObjectName("checkNoTransp");

        horizontalLayout_18->addWidget(checkNoTransp);

        pushColor = new PushColorChooser(groupBox_3);
        pushColor->setObjectName("pushColor");

        horizontalLayout_18->addWidget(pushColor);


        verticalLayout->addLayout(horizontalLayout_18);


        verticalLayout_20->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(centralwidget);
        groupBox_4->setObjectName("groupBox_4");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy3);
        groupBox_4->setMinimumSize(QSize(200, 0));
        horizontalLayout_9 = new QHBoxLayout(groupBox_4);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        label = new QLabel(groupBox_4);
        label->setObjectName("label");
        sizePolicy3.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy3);

        verticalLayout_4->addWidget(label);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        lineDirectory = new QLineEdit(groupBox_4);
        lineDirectory->setObjectName("lineDirectory");

        horizontalLayout_8->addWidget(lineDirectory);

        bntSelDir = new QToolButton(groupBox_4);
        bntSelDir->setObjectName("bntSelDir");

        horizontalLayout_8->addWidget(bntSelDir);


        verticalLayout_4->addLayout(horizontalLayout_8);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        checkSameDir = new QCheckBox(groupBox_4);
        checkSameDir->setObjectName("checkSameDir");

        horizontalLayout_7->addWidget(checkSameDir);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_3);


        verticalLayout_4->addLayout(horizontalLayout_7);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_4->addItem(verticalSpacer_3);


        horizontalLayout_9->addLayout(verticalLayout_4);

        line = new QFrame(groupBox_4);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout_9->addWidget(line);

        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setObjectName("verticalLayout_8");
        checkRename = new QCheckBox(groupBox_4);
        checkRename->setObjectName("checkRename");

        verticalLayout_8->addWidget(checkRename);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        radioPrefixSuffix = new QRadioButton(groupBox_4);
        radioPrefixSuffix->setObjectName("radioPrefixSuffix");
        radioPrefixSuffix->setChecked(true);

        horizontalLayout_3->addWidget(radioPrefixSuffix);

        radioProgressive = new QRadioButton(groupBox_4);
        radioProgressive->setObjectName("radioProgressive");

        horizontalLayout_3->addWidget(radioProgressive);


        verticalLayout_8->addLayout(horizontalLayout_3);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        lineRename = new QLineEdit(groupBox_4);
        lineRename->setObjectName("lineRename");
        lineRename->setEnabled(false);

        horizontalLayout_14->addWidget(lineRename);

        labeStartWith = new QLabel(groupBox_4);
        labeStartWith->setObjectName("labeStartWith");

        horizontalLayout_14->addWidget(labeStartWith);

        spinProgressiveRen = new QSpinBox(groupBox_4);
        spinProgressiveRen->setObjectName("spinProgressiveRen");
        spinProgressiveRen->setWrapping(false);
        spinProgressiveRen->setMaximum(99999);
        spinProgressiveRen->setValue(1);

        horizontalLayout_14->addWidget(spinProgressiveRen);


        verticalLayout_8->addLayout(horizontalLayout_14);

        line_5 = new QFrame(groupBox_4);
        line_5->setObjectName("line_5");
        line_5->setFrameShape(QFrame::Shape::HLine);
        line_5->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_8->addWidget(line_5);

        groupBox_2 = new QGroupBox(groupBox_4);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_21 = new QVBoxLayout(groupBox_2);
        verticalLayout_21->setObjectName("verticalLayout_21");
        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        radioOverwriteAsk = new QRadioButton(groupBox_2);
        radioOverwriteAsk->setObjectName("radioOverwriteAsk");
        radioOverwriteAsk->setChecked(true);

        horizontalLayout_17->addWidget(radioOverwriteAsk);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer);

        radioSkipExisting = new QRadioButton(groupBox_2);
        radioSkipExisting->setObjectName("radioSkipExisting");
        radioSkipExisting->setChecked(false);

        horizontalLayout_17->addWidget(radioSkipExisting);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_6);

        radioOverwriteExisting = new QRadioButton(groupBox_2);
        radioOverwriteExisting->setObjectName("radioOverwriteExisting");
        radioOverwriteExisting->setChecked(false);

        horizontalLayout_17->addWidget(radioOverwriteExisting);


        verticalLayout_21->addLayout(horizontalLayout_17);


        verticalLayout_8->addWidget(groupBox_2);


        horizontalLayout_9->addLayout(verticalLayout_8);


        verticalLayout_20->addWidget(groupBox_4);

        MainWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName("menubar");
        menubar->setGeometry(QRect(0, 0, 1482, 23));
        menu_File = new QMenu(menubar);
        menu_File->setObjectName("menu_File");
        menu_Edit = new QMenu(menubar);
        menu_Edit->setObjectName("menu_Edit");
        menu_Actions = new QMenu(menubar);
        menu_Actions->setObjectName("menu_Actions");
        menu_About = new QMenu(menubar);
        menu_About->setObjectName("menu_About");
        MainWindow->setMenuBar(menubar);
        statusbar = new QStatusBar(MainWindow);
        statusbar->setObjectName("statusbar");
        MainWindow->setStatusBar(statusbar);
        dockWidget = new QDockWidget(MainWindow);
        dockWidget->setObjectName("dockWidget");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Ignored);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(dockWidget->sizePolicy().hasHeightForWidth());
        dockWidget->setSizePolicy(sizePolicy4);
        dockWidget->setMinimumSize(QSize(480, 298));
        dockWidget->setFeatures(QDockWidget::DockWidgetFeature::DockWidgetFloatable|QDockWidget::DockWidgetFeature::DockWidgetMovable);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout_7 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setSizeConstraint(QLayout::SizeConstraint::SetMinimumSize);
        scrollArea = new QScrollArea(dockWidgetContents);
        scrollArea->setObjectName("scrollArea");
        sizePolicy1.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy1);
        scrollArea->setMinimumSize(QSize(0, 250));
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 448, 780));
        scrollAreaWidgetContents->setMinimumSize(QSize(0, 0));
        verticalLayout_12 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_12->setObjectName("verticalLayout_12");
        label_7 = new QLabel(scrollAreaWidgetContents);
        label_7->setObjectName("label_7");

        verticalLayout_12->addWidget(label_7);

        line_3 = new QFrame(scrollAreaWidgetContents);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_12->addWidget(line_3);

        frame = new QFrame(scrollAreaWidgetContents);
        frame->setObjectName("frame");
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setMinimumSize(QSize(320, 260));
        frame->setMaximumSize(QSize(420, 260));
        frame->setBaseSize(QSize(320, 260));
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Plain);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer_4 = new QSpacerItem(10, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 0, 1, 1);

        labelPreview = new myLabelPreviewer(frame);
        labelPreview->setObjectName("labelPreview");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(labelPreview->sizePolicy().hasHeightForWidth());
        labelPreview->setSizePolicy(sizePolicy5);
        labelPreview->setMinimumSize(QSize(50, 50));
        labelPreview->setMaximumSize(QSize(320, 240));
        labelPreview->setWordWrap(true);

        gridLayout->addWidget(labelPreview, 0, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(10, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 2, 1, 1);


        verticalLayout_12->addWidget(frame);

        checkShowPreview = new QCheckBox(scrollAreaWidgetContents);
        checkShowPreview->setObjectName("checkShowPreview");
        checkShowPreview->setChecked(true);

        verticalLayout_12->addWidget(checkShowPreview);

        line_2 = new QFrame(scrollAreaWidgetContents);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_12->addWidget(line_2);

        frame_2 = new QFrame(scrollAreaWidgetContents);
        frame_2->setObjectName("frame_2");
        sizePolicy1.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy1);
        frame_2->setMinimumSize(QSize(224, 85));
        frame_2->setMaximumSize(QSize(300, 216));
        frame_2->setBaseSize(QSize(216, 0));
        frame_2->setFrameShape(QFrame::Shape::NoFrame);
        frame_2->setFrameShadow(QFrame::Shadow::Raised);
        verticalLayout_14 = new QVBoxLayout(frame_2);
        verticalLayout_14->setObjectName("verticalLayout_14");
        verticalLayout_13 = new QVBoxLayout();
        verticalLayout_13->setObjectName("verticalLayout_13");
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_3 = new QLabel(frame_2);
        label_3->setObjectName("label_3");

        horizontalLayout_11->addWidget(label_3);

        labelType = new QLabel(frame_2);
        labelType->setObjectName("labelType");

        horizontalLayout_11->addWidget(labelType);


        verticalLayout_13->addLayout(horizontalLayout_11);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_9 = new QLabel(frame_2);
        label_9->setObjectName("label_9");

        horizontalLayout_12->addWidget(label_9);

        labelFileSize = new QLabel(frame_2);
        labelFileSize->setObjectName("labelFileSize");

        horizontalLayout_12->addWidget(labelFileSize);


        verticalLayout_13->addLayout(horizontalLayout_12);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        label_10 = new QLabel(frame_2);
        label_10->setObjectName("label_10");

        horizontalLayout_13->addWidget(label_10);

        label_ImageSize = new QLabel(frame_2);
        label_ImageSize->setObjectName("label_ImageSize");

        horizontalLayout_13->addWidget(label_ImageSize);


        verticalLayout_13->addLayout(horizontalLayout_13);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        label_11 = new QLabel(frame_2);
        label_11->setObjectName("label_11");

        horizontalLayout_16->addWidget(label_11);

        label_ImageResolution = new QLabel(frame_2);
        label_ImageResolution->setObjectName("label_ImageResolution");

        horizontalLayout_16->addWidget(label_ImageResolution);


        verticalLayout_13->addLayout(horizontalLayout_16);


        verticalLayout_14->addLayout(verticalLayout_13);


        verticalLayout_12->addWidget(frame_2);

        tabWidget = new QTabWidget(scrollAreaWidgetContents);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setTabPosition(QTabWidget::TabPosition::North);
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_11 = new QVBoxLayout(tab);
        verticalLayout_11->setObjectName("verticalLayout_11");
        groupDimensions = new QGroupBox(tab);
        groupDimensions->setObjectName("groupDimensions");
        sizePolicy3.setHeightForWidth(groupDimensions->sizePolicy().hasHeightForWidth());
        groupDimensions->setSizePolicy(sizePolicy3);
        groupDimensions->setMinimumSize(QSize(200, 0));
        groupDimensions->setCheckable(true);
        groupDimensions->setChecked(false);
        verticalLayout_6 = new QVBoxLayout(groupDimensions);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_4 = new QLabel(groupDimensions);
        label_4->setObjectName("label_4");

        verticalLayout_2->addWidget(label_4);

        label_5 = new QLabel(groupDimensions);
        label_5->setObjectName("label_5");

        verticalLayout_2->addWidget(label_5);


        horizontalLayout_5->addLayout(verticalLayout_2);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        spin_geoWidth = new QDoubleSpinBox(groupDimensions);
        spin_geoWidth->setObjectName("spin_geoWidth");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(spin_geoWidth->sizePolicy().hasHeightForWidth());
        spin_geoWidth->setSizePolicy(sizePolicy6);
        spin_geoWidth->setMinimumSize(QSize(100, 0));
        spin_geoWidth->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        spin_geoWidth->setButtonSymbols(QAbstractSpinBox::ButtonSymbols::UpDownArrows);
        spin_geoWidth->setCorrectionMode(QAbstractSpinBox::CorrectionMode::CorrectToNearestValue);
        spin_geoWidth->setKeyboardTracking(false);
        spin_geoWidth->setProperty("showGroupSeparator", QVariant(false));
        spin_geoWidth->setDecimals(0);
        spin_geoWidth->setMinimum(0.000000000000000);
        spin_geoWidth->setMaximum(262144.000000000000000);
        spin_geoWidth->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spin_geoWidth->setValue(100.000000000000000);

        verticalLayout_3->addWidget(spin_geoWidth);

        spin_geoHeight = new QDoubleSpinBox(groupDimensions);
        spin_geoHeight->setObjectName("spin_geoHeight");
        sizePolicy6.setHeightForWidth(spin_geoHeight->sizePolicy().hasHeightForWidth());
        spin_geoHeight->setSizePolicy(sizePolicy6);
        spin_geoHeight->setMinimumSize(QSize(100, 0));
        spin_geoHeight->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        spin_geoHeight->setInputMethodHints(Qt::InputMethodHint::ImhFormattedNumbersOnly);
        spin_geoHeight->setCorrectionMode(QAbstractSpinBox::CorrectionMode::CorrectToNearestValue);
        spin_geoHeight->setKeyboardTracking(false);
        spin_geoHeight->setDecimals(0);
        spin_geoHeight->setMinimum(0.000000000000000);
        spin_geoHeight->setMaximum(262144.000000000000000);
        spin_geoHeight->setStepType(QAbstractSpinBox::StepType::AdaptiveDecimalStepType);
        spin_geoHeight->setValue(100.000000000000000);

        verticalLayout_3->addWidget(spin_geoHeight);


        horizontalLayout_5->addLayout(verticalLayout_3);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        comboResizeValues = new QComboBox(groupDimensions);
        comboResizeValues->setObjectName("comboResizeValues");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(comboResizeValues->sizePolicy().hasHeightForWidth());
        comboResizeValues->setSizePolicy(sizePolicy7);
        comboResizeValues->setMinimumSize(QSize(30, 0));
        comboResizeValues->setMaximumSize(QSize(16777215, 16777215));

        verticalLayout_5->addWidget(comboResizeValues);


        horizontalLayout_5->addLayout(verticalLayout_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        pushReset = new QPushButton(groupDimensions);
        pushReset->setObjectName("pushReset");
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/Images/res/reset.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushReset->setIcon(icon10);

        horizontalLayout_2->addWidget(pushReset);

        pushLinkAspect = new QPushButton(groupDimensions);
        pushLinkAspect->setObjectName("pushLinkAspect");
        pushLinkAspect->setToolTipDuration(-1);
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/Images/res/lock.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        pushLinkAspect->setIcon(icon11);
        pushLinkAspect->setCheckable(true);

        horizontalLayout_2->addWidget(pushLinkAspect);


        horizontalLayout_5->addLayout(horizontalLayout_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);


        verticalLayout_6->addLayout(horizontalLayout_5);

        labelPixelGeometry = new QLabel(groupDimensions);
        labelPixelGeometry->setObjectName("labelPixelGeometry");

        verticalLayout_6->addWidget(labelPixelGeometry);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        checkRelative = new QCheckBox(groupDimensions);
        checkRelative->setObjectName("checkRelative");
        checkRelative->setChecked(true);

        horizontalLayout_20->addWidget(checkRelative);

        labelAspectRatioHelp = new QLabel(groupDimensions);
        labelAspectRatioHelp->setObjectName("labelAspectRatioHelp");

        horizontalLayout_20->addWidget(labelAspectRatioHelp);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_20->addItem(horizontalSpacer_7);


        verticalLayout_6->addLayout(horizontalLayout_20);


        verticalLayout_11->addWidget(groupDimensions);

        groupResolution = new QGroupBox(tab);
        groupResolution->setObjectName("groupResolution");
        sizePolicy.setHeightForWidth(groupResolution->sizePolicy().hasHeightForWidth());
        groupResolution->setSizePolicy(sizePolicy);
        groupResolution->setCheckable(true);
        groupResolution->setChecked(false);
        horizontalLayout_15 = new QHBoxLayout(groupResolution);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        verticalLayout_9 = new QVBoxLayout();
        verticalLayout_9->setObjectName("verticalLayout_9");
        label_6 = new QLabel(groupResolution);
        label_6->setObjectName("label_6");

        verticalLayout_9->addWidget(label_6);

        label_8 = new QLabel(groupResolution);
        label_8->setObjectName("label_8");

        verticalLayout_9->addWidget(label_8);


        horizontalLayout_6->addLayout(verticalLayout_9);

        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setObjectName("verticalLayout_10");
        spin_resX = new QDoubleSpinBox(groupResolution);
        spin_resX->setObjectName("spin_resX");
        spin_resX->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        spin_resX->setSuffix(QString::fromUtf8(" dpi"));
        spin_resX->setDecimals(0);
        spin_resX->setMaximum(3000.000000000000000);
        spin_resX->setValue(0.000000000000000);

        verticalLayout_10->addWidget(spin_resX);

        spin_resY = new QDoubleSpinBox(groupResolution);
        spin_resY->setObjectName("spin_resY");
        spin_resY->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        spin_resY->setSuffix(QString::fromUtf8(" dpi"));
        spin_resY->setDecimals(0);
        spin_resY->setMaximum(3000.000000000000000);
        spin_resY->setValue(0.000000000000000);

        verticalLayout_10->addWidget(spin_resY);


        horizontalLayout_6->addLayout(verticalLayout_10);


        horizontalLayout_15->addLayout(horizontalLayout_6);


        verticalLayout_11->addWidget(groupResolution);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_15 = new QVBoxLayout(tab_2);
        verticalLayout_15->setObjectName("verticalLayout_15");
        groupBox = new QGroupBox(tab_2);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(false);
        groupBox->setCheckable(false);
        groupBox->setChecked(false);
        verticalLayout_18 = new QVBoxLayout(groupBox);
        verticalLayout_18->setObjectName("verticalLayout_18");
        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        verticalLayout_18->addWidget(label_12);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        radioRotNo = new QRadioButton(groupBox);
        buttonGroup = new QButtonGroup(MainWindow);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(radioRotNo);
        radioRotNo->setObjectName("radioRotNo");
        radioRotNo->setChecked(true);

        horizontalLayout_19->addWidget(radioRotNo);

        verticalLayout_17 = new QVBoxLayout();
        verticalLayout_17->setObjectName("verticalLayout_17");
        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        radioRotPos90 = new QRadioButton(groupBox);
        buttonGroup->addButton(radioRotPos90);
        radioRotPos90->setObjectName("radioRotPos90");
        QIcon icon12;
        icon12.addFile(QString::fromUtf8(":/Images/res/90p.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        radioRotPos90->setIcon(icon12);

        horizontalLayout_10->addWidget(radioRotPos90);

        radioRotNeg90 = new QRadioButton(groupBox);
        buttonGroup->addButton(radioRotNeg90);
        radioRotNeg90->setObjectName("radioRotNeg90");
        QIcon icon13;
        icon13.addFile(QString::fromUtf8(":/Images/res/90m.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        radioRotNeg90->setIcon(icon13);

        horizontalLayout_10->addWidget(radioRotNeg90);


        verticalLayout_17->addLayout(horizontalLayout_10);

        radioRot180 = new QRadioButton(groupBox);
        buttonGroup->addButton(radioRot180);
        radioRot180->setObjectName("radioRot180");
        QIcon icon14;
        icon14.addFile(QString::fromUtf8(":/Images/res/180.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        radioRot180->setIcon(icon14);

        verticalLayout_17->addWidget(radioRot180);


        horizontalLayout_19->addLayout(verticalLayout_17);


        verticalLayout_18->addLayout(horizontalLayout_19);

        line_4 = new QFrame(groupBox);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_18->addWidget(line_4);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");

        verticalLayout_18->addWidget(label_13);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        radioFlipNo = new QRadioButton(groupBox);
        buttonGroup_2 = new QButtonGroup(MainWindow);
        buttonGroup_2->setObjectName("buttonGroup_2");
        buttonGroup_2->addButton(radioFlipNo);
        radioFlipNo->setObjectName("radioFlipNo");
        radioFlipNo->setChecked(true);
        radioFlipNo->setAutoExclusive(true);

        horizontalLayout_4->addWidget(radioFlipNo);

        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setObjectName("verticalLayout_16");
        radioFlipH = new QRadioButton(groupBox);
        buttonGroup_2->addButton(radioFlipH);
        radioFlipH->setObjectName("radioFlipH");
        QIcon icon15;
        icon15.addFile(QString::fromUtf8(":/Images/res/h.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        radioFlipH->setIcon(icon15);

        verticalLayout_16->addWidget(radioFlipH);

        radioFlipV = new QRadioButton(groupBox);
        buttonGroup_2->addButton(radioFlipV);
        radioFlipV->setObjectName("radioFlipV");
        QIcon icon16;
        icon16.addFile(QString::fromUtf8(":/Images/res/v.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        radioFlipV->setIcon(icon16);

        verticalLayout_16->addWidget(radioFlipV);


        horizontalLayout_4->addLayout(verticalLayout_16);


        verticalLayout_18->addLayout(horizontalLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_18->addItem(verticalSpacer_2);


        verticalLayout_15->addWidget(groupBox);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_12->addWidget(tabWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_12->addItem(verticalSpacer);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_7->addWidget(scrollArea);

        dockWidget->setWidget(dockWidgetContents);
        MainWindow->addDockWidget(Qt::DockWidgetArea::LeftDockWidgetArea, dockWidget);
        toolBar = new QToolBar(MainWindow);
        toolBar->setObjectName("toolBar");
        toolBar->setMovable(false);
        toolBar->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        MainWindow->addToolBar(Qt::ToolBarArea::TopToolBarArea, toolBar);

        menubar->addAction(menu_File->menuAction());
        menubar->addAction(menu_Edit->menuAction());
        menubar->addAction(menu_Actions->menuAction());
        menubar->addAction(menu_About->menuAction());
        menu_About->addAction(actionHelp);
        menu_About->addSeparator();
        menu_About->addAction(actionDonatePaypal);
        menu_About->addSeparator();
        menu_About->addAction(actionCheckForUpdates);
        menu_About->addAction(actionReportBug);
        menu_About->addSeparator();
        menu_About->addAction(actionInfo);
        toolBar->addAction(actionAddFiles);
        toolBar->addSeparator();
        toolBar->addAction(actionConvert);
        toolBar->addSeparator();
        toolBar->addAction(actionRemoveItems);
        toolBar->addAction(actionRemoveAllItems);
        toolBar->addSeparator();
        toolBar->addAction(actionCheckItems);
        toolBar->addAction(actionCheckAllItems);

        retranslateUi(MainWindow);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "Converseen", nullptr));
        actionOpenFiles->setText(QCoreApplication::translate("MainWindow", "&Open images", nullptr));
#if QT_CONFIG(shortcut)
        actionOpenFiles->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionAddFiles->setText(QCoreApplication::translate("MainWindow", "&Add images", nullptr));
#if QT_CONFIG(shortcut)
        actionAddFiles->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionRemoveItems->setText(QCoreApplication::translate("MainWindow", "&Remove images", nullptr));
#if QT_CONFIG(tooltip)
        actionRemoveItems->setToolTip(QCoreApplication::translate("MainWindow", "Remove selected pictures", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionRemoveItems->setShortcut(QCoreApplication::translate("MainWindow", "Del", nullptr));
#endif // QT_CONFIG(shortcut)
        actionRemoveAllItems->setText(QCoreApplication::translate("MainWindow", "Remove &all", nullptr));
#if QT_CONFIG(tooltip)
        actionRemoveAllItems->setToolTip(QCoreApplication::translate("MainWindow", "Remove all pictures", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionRemoveAllItems->setShortcut(QCoreApplication::translate("MainWindow", "Alt+Del", nullptr));
#endif // QT_CONFIG(shortcut)
        actionCheckItems->setText(QCoreApplication::translate("MainWindow", "&Check", nullptr));
#if QT_CONFIG(tooltip)
        actionCheckItems->setToolTip(QCoreApplication::translate("MainWindow", "Check selected items", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionCheckItems->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+H", nullptr));
#endif // QT_CONFIG(shortcut)
        actionCheckAllItems->setText(QCoreApplication::translate("MainWindow", "Check a&ll", nullptr));
#if QT_CONFIG(tooltip)
        actionCheckAllItems->setToolTip(QCoreApplication::translate("MainWindow", "Check all items", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionCheckAllItems->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+H", nullptr));
#endif // QT_CONFIG(shortcut)
        actionConvert->setText(QCoreApplication::translate("MainWindow", "&Convert", nullptr));
#if QT_CONFIG(tooltip)
        actionConvert->setToolTip(QCoreApplication::translate("MainWindow", "Start the conversion process", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionConvert->setShortcut(QCoreApplication::translate("MainWindow", "F5", nullptr));
#endif // QT_CONFIG(shortcut)
        actionShowOptions->setText(QCoreApplication::translate("MainWindow", "&Settings", nullptr));
#if QT_CONFIG(tooltip)
        actionShowOptions->setToolTip(QCoreApplication::translate("MainWindow", "Open the settings dialog", nullptr));
#endif // QT_CONFIG(tooltip)
        actionClose->setText(QCoreApplication::translate("MainWindow", "&Exit", nullptr));
#if QT_CONFIG(shortcut)
        actionClose->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Q", nullptr));
#endif // QT_CONFIG(shortcut)
        actionUncheckAllItems->setText(QCoreApplication::translate("MainWindow", "Uncheck all &items", nullptr));
#if QT_CONFIG(shortcut)
        actionUncheckAllItems->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+J", nullptr));
#endif // QT_CONFIG(shortcut)
        actionUncheckItems->setText(QCoreApplication::translate("MainWindow", "&Uncheck Items", nullptr));
#if QT_CONFIG(tooltip)
        actionUncheckItems->setToolTip(QCoreApplication::translate("MainWindow", "Uncheck selected items", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionUncheckItems->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+J", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInfo->setText(QCoreApplication::translate("MainWindow", "&About", nullptr));
        actionDonatePaypal->setText(QCoreApplication::translate("MainWindow", "&Donate!", nullptr));
#if QT_CONFIG(tooltip)
        actionDonatePaypal->setToolTip(QCoreApplication::translate("MainWindow", "Donate via Paypal, Ko-Fi, Cryptocurrencies", nullptr));
#endif // QT_CONFIG(tooltip)
        actionReportBug->setText(QCoreApplication::translate("MainWindow", "&Report bug...", nullptr));
        actionImportPDFFile->setText(QCoreApplication::translate("MainWindow", "Import PDF file", nullptr));
        actionImportWindowsIconIco->setText(QCoreApplication::translate("MainWindow", "Import windows icon (*.ico)", nullptr));
#if QT_CONFIG(tooltip)
        actionImportWindowsIconIco->setToolTip(QCoreApplication::translate("MainWindow", "Import windows icon (*.ico *.icon)", nullptr));
#endif // QT_CONFIG(tooltip)
        actionCheckForUpdates->setText(QCoreApplication::translate("MainWindow", "&Check for updates", nullptr));
#if QT_CONFIG(tooltip)
        actionCheckForUpdates->setToolTip(QCoreApplication::translate("MainWindow", "Check if a new version of Converseen is available", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAddDirectory->setText(QCoreApplication::translate("MainWindow", "Import directory", nullptr));
#if QT_CONFIG(tooltip)
        actionAddDirectory->setToolTip(QCoreApplication::translate("MainWindow", "Import directory", nullptr));
#endif // QT_CONFIG(tooltip)
        actionHelp->setText(QCoreApplication::translate("MainWindow", "&Online Help", nullptr));
#if QT_CONFIG(tooltip)
        actionHelp->setToolTip(QCoreApplication::translate("MainWindow", "Open online help", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionHelp->setShortcut(QCoreApplication::translate("MainWindow", "F1", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInvertCheckedItems->setText(QCoreApplication::translate("MainWindow", "Invert Checked Items", nullptr));
#if QT_CONFIG(shortcut)
        actionInvertCheckedItems->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+I", nullptr));
#endif // QT_CONFIG(shortcut)
        groupBox_3->setTitle(QCoreApplication::translate("MainWindow", "Conversion Formats", nullptr));
        label_2->setText(QCoreApplication::translate("MainWindow", "Convert to:", nullptr));
#if QT_CONFIG(statustip)
        btnFormatOptions->setStatusTip(QCoreApplication::translate("MainWindow", "Show image settings dialog...", nullptr));
#endif // QT_CONFIG(statustip)
        btnFormatOptions->setText(QCoreApplication::translate("MainWindow", "Images settings", nullptr));
        checkNoTransp->setText(QCoreApplication::translate("MainWindow", "Replace transparent background", nullptr));
        pushColor->setText(QCoreApplication::translate("MainWindow", "Choose color", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("MainWindow", "Output options", nullptr));
        label->setText(QCoreApplication::translate("MainWindow", "Save in:", nullptr));
#if QT_CONFIG(statustip)
        bntSelDir->setStatusTip(QCoreApplication::translate("MainWindow", "Open output directory", nullptr));
#endif // QT_CONFIG(statustip)
        bntSelDir->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
        checkSameDir->setText(QCoreApplication::translate("MainWindow", "Image's directory", nullptr));
        checkRename->setText(QCoreApplication::translate("MainWindow", "Rename:", nullptr));
        radioPrefixSuffix->setText(QCoreApplication::translate("MainWindow", "Prefi&x/Suffix", nullptr));
        radioProgressive->setText(QCoreApplication::translate("MainWindow", "Progressi&ve Number", nullptr));
#if QT_CONFIG(tooltip)
        lineRename->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        lineRename->setText(QCoreApplication::translate("MainWindow", "#_copy", nullptr));
        labeStartWith->setText(QCoreApplication::translate("MainWindow", "Start with:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("MainWindow", "File Overwrite Settings", nullptr));
#if QT_CONFIG(tooltip)
        radioOverwriteAsk->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>If the processed output file has the same name as an existing file in the destination folder, you will be prompted to choose an action manually.</p><p>You can either rename it or overwrite the existing file.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        radioOverwriteAsk->setText(QCoreApplication::translate("MainWindow", "Always Ask", nullptr));
#if QT_CONFIG(tooltip)
        radioSkipExisting->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>If the processed output file has the same name as an existing file in the same folder, the conversion process will automatically <span style=\" font-weight:700;\">skip</span> it to <span style=\" font-weight:700;\">preserve</span> the one in the destination directory.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        radioSkipExisting->setText(QCoreApplication::translate("MainWindow", "Skip Existing Files", nullptr));
#if QT_CONFIG(tooltip)
        radioOverwriteExisting->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>If the processed output file has the same name as an existing file in the same folder, the conversion process will <span style=\" font-weight:700;\">overwrite</span> the original file, <span style=\" font-weight:700;\">permanently deleting it</span>.</p><p><span style=\" font-weight:700;\">Please, use caution when selecting this option!</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        radioOverwriteExisting->setText(QCoreApplication::translate("MainWindow", "Overwrite Existing Files", nullptr));
        menu_File->setTitle(QCoreApplication::translate("MainWindow", "&File", nullptr));
        menu_Edit->setTitle(QCoreApplication::translate("MainWindow", "&Edit", nullptr));
        menu_Actions->setTitle(QCoreApplication::translate("MainWindow", "&Actions", nullptr));
        menu_About->setTitle(QCoreApplication::translate("MainWindow", "&Help", nullptr));
        dockWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "Actio&ns Panel", nullptr));
        label_7->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Preview:</span></p></body></html>", nullptr));
        labelPreview->setText(QString());
        checkShowPreview->setText(QCoreApplication::translate("MainWindow", "Show preview", nullptr));
        label_3->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"right\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt; color:#828282;\">Type:</span></p></body></html>", nullptr));
        labelType->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\"> - </span></p></body></html>", nullptr));
        label_9->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"right\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt; color:#828282;\">File size:</span></p></body></html>", nullptr));
        labelFileSize->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\"> - </span></p></body></html>", nullptr));
        label_10->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"right\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt; color:#828282;\">Image size:</span></p></body></html>", nullptr));
        label_ImageSize->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\"> - </span></p></body></html>", nullptr));
        label_11->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"right\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt; color:#828282;\">Image resolution:</span></p></body></html>", nullptr));
        label_ImageResolution->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\"> - </span></p></body></html>", nullptr));
        groupDimensions->setTitle(QCoreApplication::translate("MainWindow", "Scale image", nullptr));
        label_4->setText(QCoreApplication::translate("MainWindow", "Width:", nullptr));
        label_5->setText(QCoreApplication::translate("MainWindow", "Height:", nullptr));
#if QT_CONFIG(tooltip)
        pushReset->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p><span style=\" font-weight:700;\">Load Image Sizes</span></p><p>If '<span style=\" font-weight:700;\">px'</span> is selected, the original image sizes will be loaded into the <span style=\" font-weight:700;\">Width/Height</span> fields. </p><p>If <span style=\" font-weight:700;\">'%'</span> is selected, it restores the <span style=\" font-weight:700;\">Width/Height</span> fields to <span style=\" font-weight:700;\">100%</span>.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pushReset->setText(QString());
#if QT_CONFIG(tooltip)
        pushLinkAspect->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p><span style=\" font-weight:700;\">Link Aspect Ratio with Selected Image</span></p><p>Automatically adjusts the aspect ratio values when you enter a value in the <span style=\" font-weight:700;\">Width/Height</span> fields.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        pushLinkAspect->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        pushLinkAspect->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        pushLinkAspect->setText(QString());
        labelPixelGeometry->setText(QCoreApplication::translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\">0 x 0 pixel</span></p></body></html>", nullptr));
        checkRelative->setText(QCoreApplication::translate("MainWindow", "Maintain aspect ratio", nullptr));
#if QT_CONFIG(tooltip)
        labelAspectRatioHelp->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p><span style=\" font-weight:700;\">Maintain Aspect Ratio</span><br/>Keeps the image proportions unchanged.<br/><br/><span style=\" font-weight:700;\">Prioritize Width or Height</span><br/>Enter <span style=\" font-weight:700;\">0</span> for the side to ignore. The other value is kept constant, and the ignored dimension is calculated automatically.<br/><span style=\" font-weight:700;\">Example:</span><span style=\" font-style:italic;\"> Height 800 px, Width 0 px</span> \342\206\222 height stays <span style=\" font-style:italic;\">800 px</span>, width is calculated <span style=\" font-style:italic;\">automatically</span>.<br/>Works the same in <span style=\" font-weight:700;\">percentage</span> mode. </p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        labelAspectRatioHelp->setText(QCoreApplication::translate("MainWindow", "<html><head/><body><p><a href=\"#\"><span style=\" text-decoration: underline; color:#007af4; vertical-align:super;\">?</span></a></p></body></html>", nullptr));
        groupResolution->setTitle(QCoreApplication::translate("MainWindow", "Resolution", nullptr));
        label_6->setText(QCoreApplication::translate("MainWindow", "Resolution X:", nullptr));
        label_8->setText(QCoreApplication::translate("MainWindow", "Resolution Y:", nullptr));
        spin_resX->setSpecialValueText(QString());
        spin_resY->setSpecialValueText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("MainWindow", "Dimensions", nullptr));
        groupBox->setTitle(QCoreApplication::translate("MainWindow", "Rotate and flip", nullptr));
        label_12->setText(QCoreApplication::translate("MainWindow", "Rotate image:", nullptr));
        radioRotNo->setText(QCoreApplication::translate("MainWindow", "No rotation", nullptr));
        radioRotPos90->setText(QCoreApplication::translate("MainWindow", "+ &90\302\260", nullptr));
        radioRotNeg90->setText(QCoreApplication::translate("MainWindow", "- 9&0\302\260", nullptr));
        radioRot180->setText(QCoreApplication::translate("MainWindow", "&180\302\260", nullptr));
        label_13->setText(QCoreApplication::translate("MainWindow", "Flip image:", nullptr));
        radioFlipNo->setText(QCoreApplication::translate("MainWindow", "No flip", nullptr));
        radioFlipH->setText(QCoreApplication::translate("MainWindow", "Horizontally", nullptr));
        radioFlipV->setText(QCoreApplication::translate("MainWindow", "Vertically", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("MainWindow", "Rotate and flip", nullptr));
        toolBar->setWindowTitle(QCoreApplication::translate("MainWindow", "toolBar", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
