/********************************************************************************
** Form generated from reading UI file 'dialogquality.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGQUALITY_H
#define UI_DIALOGQUALITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "src/combofilters.h"

QT_BEGIN_NAMESPACE

class Ui_DialogQuality
{
public:
    QVBoxLayout *verticalLayout_10;
    QToolBox *toolBox;
    QWidget *jpeg;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label;
    QLabel *labelJpegHelp;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QSlider *sliderJpegQ;
    QSpinBox *spinJpegQ;
    QWidget *PngMng;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_2;
    QLabel *labelPngHelp;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSlider *sliderPngQ;
    QSpinBox *spinPngQ;
    QWidget *WebP;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *checkWebPLCompression;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_8;
    QSlider *sliderWebPCompression;
    QSpinBox *spinWebPCompression;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_7;
    QSlider *sliderWebPQuality;
    QSpinBox *spinWebPQuality;
    QCheckBox *checkWebPDithering;
    QFrame *line;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_3;
    Combofilters *comboFilters;
    QCheckBox *checkRemoveMetadata;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushOk;
    QPushButton *pushCancel;

    void setupUi(QDialog *DialogQuality)
    {
        if (DialogQuality->objectName().isEmpty())
            DialogQuality->setObjectName("DialogQuality");
        DialogQuality->resize(524, 606);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Ignored);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DialogQuality->sizePolicy().hasHeightForWidth());
        DialogQuality->setSizePolicy(sizePolicy);
        verticalLayout_10 = new QVBoxLayout(DialogQuality);
        verticalLayout_10->setObjectName("verticalLayout_10");
        toolBox = new QToolBox(DialogQuality);
        toolBox->setObjectName("toolBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(toolBox->sizePolicy().hasHeightForWidth());
        toolBox->setSizePolicy(sizePolicy1);
        toolBox->setFrameShape(QFrame::NoFrame);
        jpeg = new QWidget();
        jpeg->setObjectName("jpeg");
        jpeg->setGeometry(QRect(0, 0, 502, 134));
        sizePolicy.setHeightForWidth(jpeg->sizePolicy().hasHeightForWidth());
        jpeg->setSizePolicy(sizePolicy);
        verticalLayout_7 = new QVBoxLayout(jpeg);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setSizeConstraint(QLayout::SetDefaultConstraint);
        groupBox = new QGroupBox(jpeg);
        groupBox->setObjectName("groupBox");
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout_6->addWidget(label);

        labelJpegHelp = new QLabel(groupBox);
        labelJpegHelp->setObjectName("labelJpegHelp");

        horizontalLayout_6->addWidget(labelJpegHelp);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_6);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        sliderJpegQ = new QSlider(groupBox);
        sliderJpegQ->setObjectName("sliderJpegQ");
        sliderJpegQ->setMinimum(1);
        sliderJpegQ->setMaximum(100);
        sliderJpegQ->setValue(75);
        sliderJpegQ->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(sliderJpegQ);

        spinJpegQ = new QSpinBox(groupBox);
        spinJpegQ->setObjectName("spinJpegQ");
        spinJpegQ->setMaximum(100);

        horizontalLayout->addWidget(spinJpegQ);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_7->addWidget(groupBox);

        toolBox->addItem(jpeg, QString::fromUtf8("Jpeg"));
        PngMng = new QWidget();
        PngMng->setObjectName("PngMng");
        sizePolicy.setHeightForWidth(PngMng->sizePolicy().hasHeightForWidth());
        PngMng->setSizePolicy(sizePolicy);
        verticalLayout_8 = new QVBoxLayout(PngMng);
        verticalLayout_8->setObjectName("verticalLayout_8");
        groupBox_2 = new QGroupBox(PngMng);
        groupBox_2->setObjectName("groupBox_2");
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        groupBox_2->setToolTipDuration(-1);
        verticalLayout_4 = new QVBoxLayout(groupBox_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);

        labelPngHelp = new QLabel(groupBox_2);
        labelPngHelp->setObjectName("labelPngHelp");

        horizontalLayout_5->addWidget(labelPngHelp);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);


        verticalLayout_4->addLayout(horizontalLayout_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        sliderPngQ = new QSlider(groupBox_2);
        sliderPngQ->setObjectName("sliderPngQ");
        sliderPngQ->setToolTipDuration(-1);
        sliderPngQ->setMaximum(9);
        sliderPngQ->setValue(7);
        sliderPngQ->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(sliderPngQ);

        spinPngQ = new QSpinBox(groupBox_2);
        spinPngQ->setObjectName("spinPngQ");
        spinPngQ->setMaximum(100);

        horizontalLayout_2->addWidget(spinPngQ);


        verticalLayout_4->addLayout(horizontalLayout_2);


        verticalLayout_8->addWidget(groupBox_2);

        toolBox->addItem(PngMng, QString::fromUtf8("Png/Mng"));
        WebP = new QWidget();
        WebP->setObjectName("WebP");
        WebP->setGeometry(QRect(0, 0, 502, 270));
        sizePolicy.setHeightForWidth(WebP->sizePolicy().hasHeightForWidth());
        WebP->setSizePolicy(sizePolicy);
        verticalLayout_9 = new QVBoxLayout(WebP);
        verticalLayout_9->setObjectName("verticalLayout_9");
        groupBox_4 = new QGroupBox(WebP);
        groupBox_4->setObjectName("groupBox_4");
        sizePolicy1.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy1);
        verticalLayout_3 = new QVBoxLayout(groupBox_4);
        verticalLayout_3->setObjectName("verticalLayout_3");
        checkWebPLCompression = new QCheckBox(groupBox_4);
        checkWebPLCompression->setObjectName("checkWebPLCompression");

        verticalLayout_3->addWidget(checkWebPLCompression);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName("verticalLayout_5");
        label_5 = new QLabel(groupBox_4);
        label_5->setObjectName("label_5");

        verticalLayout_5->addWidget(label_5);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        sliderWebPCompression = new QSlider(groupBox_4);
        sliderWebPCompression->setObjectName("sliderWebPCompression");
        sliderWebPCompression->setMaximum(6);
        sliderWebPCompression->setPageStep(1);
        sliderWebPCompression->setSliderPosition(0);
        sliderWebPCompression->setOrientation(Qt::Horizontal);
        sliderWebPCompression->setTickPosition(QSlider::TicksAbove);
        sliderWebPCompression->setTickInterval(1);

        horizontalLayout_8->addWidget(sliderWebPCompression);

        spinWebPCompression = new QSpinBox(groupBox_4);
        spinWebPCompression->setObjectName("spinWebPCompression");
        spinWebPCompression->setMaximum(6);

        horizontalLayout_8->addWidget(spinWebPCompression);


        verticalLayout_5->addLayout(horizontalLayout_8);


        verticalLayout_3->addLayout(verticalLayout_5);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_4 = new QLabel(groupBox_4);
        label_4->setObjectName("label_4");

        verticalLayout_2->addWidget(label_4);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        sliderWebPQuality = new QSlider(groupBox_4);
        sliderWebPQuality->setObjectName("sliderWebPQuality");
        sliderWebPQuality->setMaximum(100);
        sliderWebPQuality->setOrientation(Qt::Horizontal);

        horizontalLayout_7->addWidget(sliderWebPQuality);

        spinWebPQuality = new QSpinBox(groupBox_4);
        spinWebPQuality->setObjectName("spinWebPQuality");
        spinWebPQuality->setMaximum(100);

        horizontalLayout_7->addWidget(spinWebPQuality);


        verticalLayout_2->addLayout(horizontalLayout_7);


        verticalLayout_3->addLayout(verticalLayout_2);

        checkWebPDithering = new QCheckBox(groupBox_4);
        checkWebPDithering->setObjectName("checkWebPDithering");

        verticalLayout_3->addWidget(checkWebPDithering);


        verticalLayout_9->addWidget(groupBox_4);

        toolBox->addItem(WebP, QString::fromUtf8("WebP"));

        verticalLayout_10->addWidget(toolBox);

        line = new QFrame(DialogQuality);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(line);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer);

        groupBox_3 = new QGroupBox(DialogQuality);
        groupBox_3->setObjectName("groupBox_3");
        sizePolicy1.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy1);
        verticalLayout_6 = new QVBoxLayout(groupBox_3);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName("label_3");

        horizontalLayout_4->addWidget(label_3);

        comboFilters = new Combofilters(groupBox_3);
        comboFilters->setObjectName("comboFilters");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(comboFilters->sizePolicy().hasHeightForWidth());
        comboFilters->setSizePolicy(sizePolicy2);

        horizontalLayout_4->addWidget(comboFilters);


        verticalLayout_6->addLayout(horizontalLayout_4);


        verticalLayout_10->addWidget(groupBox_3);

        checkRemoveMetadata = new QCheckBox(DialogQuality);
        checkRemoveMetadata->setObjectName("checkRemoveMetadata");

        verticalLayout_10->addWidget(checkRemoveMetadata);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        pushOk = new QPushButton(DialogQuality);
        pushOk->setObjectName("pushOk");

        horizontalLayout_3->addWidget(pushOk);

        pushCancel = new QPushButton(DialogQuality);
        pushCancel->setObjectName("pushCancel");

        horizontalLayout_3->addWidget(pushCancel);


        verticalLayout_10->addLayout(horizontalLayout_3);


        retranslateUi(DialogQuality);

        toolBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DialogQuality);
    } // setupUi

    void retranslateUi(QDialog *DialogQuality)
    {
        DialogQuality->setWindowTitle(QCoreApplication::translate("DialogQuality", "Image settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("DialogQuality", "Jpeg compression level", nullptr));
        label->setText(QCoreApplication::translate("DialogQuality", "Quality 1 - 100:", nullptr));
#if QT_CONFIG(tooltip)
        labelJpegHelp->setToolTip(QCoreApplication::translate("DialogQuality", "<html><head/><body><p>For the JPEG image formats, quality is 1 (lowest image quality and highest compression) to 100 (best quality but least effective compression).</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        labelJpegHelp->setText(QCoreApplication::translate("DialogQuality", "<html><head/><body><p><a href=\"#\"><span style=\" text-decoration: underline; color:#007af4; vertical-align:super;\">?</span></a></p></body></html>", nullptr));
        toolBox->setItemText(toolBox->indexOf(jpeg), QCoreApplication::translate("DialogQuality", "Jpeg", nullptr));
#if QT_CONFIG(tooltip)
        groupBox_2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        groupBox_2->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        groupBox_2->setTitle(QCoreApplication::translate("DialogQuality", "Png/Mng compression level", nullptr));
        label_2->setText(QCoreApplication::translate("DialogQuality", "Quality 0 - 9:", nullptr));
#if QT_CONFIG(tooltip)
        labelPngHelp->setToolTip(QCoreApplication::translate("DialogQuality", "<html><head/><body><p>Sets the zlib compression level from 1 to 9 (1 is lowest and 9 is highest).</p><p>For compression level 0, the Huffman-only strategy is used, which is fastest but not necessarily the worst compression.</p><p>PNG uses a 'lossless' compression method, so increasing the compression does NOT reduce your image quality.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        labelPngHelp->setText(QCoreApplication::translate("DialogQuality", "<html><head/><body><p><a href=\"#\"><span style=\" text-decoration: underline; color:#007af4; vertical-align:super;\">?</span></a></p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        sliderPngQ->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        spinPngQ->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        toolBox->setItemText(toolBox->indexOf(PngMng), QCoreApplication::translate("DialogQuality", "Png/Mng", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("DialogQuality", "WebP General Settings", nullptr));
        checkWebPLCompression->setText(QCoreApplication::translate("DialogQuality", "Enable Lossless Compression", nullptr));
        label_5->setText(QCoreApplication::translate("DialogQuality", "Compression Method:", nullptr));
        label_4->setText(QCoreApplication::translate("DialogQuality", "Quality:", nullptr));
        spinWebPQuality->setSuffix(QCoreApplication::translate("DialogQuality", "%", nullptr));
        checkWebPDithering->setText(QCoreApplication::translate("DialogQuality", "Enable Dithering", nullptr));
        toolBox->setItemText(toolBox->indexOf(WebP), QCoreApplication::translate("DialogQuality", "WebP", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("DialogQuality", "Interpolation", nullptr));
        label_3->setText(QCoreApplication::translate("DialogQuality", "Filter:", nullptr));
        checkRemoveMetadata->setText(QCoreApplication::translate("DialogQuality", "Remove image's metadata", nullptr));
#if QT_CONFIG(tooltip)
        pushOk->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        pushOk->setText(QCoreApplication::translate("DialogQuality", "Ok", nullptr));
        pushCancel->setText(QCoreApplication::translate("DialogQuality", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogQuality: public Ui_DialogQuality {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGQUALITY_H
