/********************************************************************************
** Form generated from reading UI file 'dialogoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGOPTIONS_H
#define UI_DIALOGOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogOptions
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *comboLangs;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QComboBox *comboStyle;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QRadioButton *radioAskFirst;
    QRadioButton *radioOverwrite;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *checkCheckUpdates;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushOk;
    QPushButton *pushCancel;

    void setupUi(QDialog *DialogOptions)
    {
        if (DialogOptions->objectName().isEmpty())
            DialogOptions->setObjectName("DialogOptions");
        DialogOptions->resize(424, 426);
        verticalLayout_2 = new QVBoxLayout(DialogOptions);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(DialogOptions);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        comboLangs = new QComboBox(groupBox);
        comboLangs->setObjectName("comboLangs");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboLangs->sizePolicy().hasHeightForWidth());
        comboLangs->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(comboLangs);


        verticalLayout_2->addWidget(groupBox);

        groupBox_4 = new QGroupBox(DialogOptions);
        groupBox_4->setObjectName("groupBox_4");
        horizontalLayout_3 = new QHBoxLayout(groupBox_4);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_2 = new QLabel(groupBox_4);
        label_2->setObjectName("label_2");

        horizontalLayout_3->addWidget(label_2);

        comboStyle = new QComboBox(groupBox_4);
        comboStyle->setObjectName("comboStyle");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboStyle->sizePolicy().hasHeightForWidth());
        comboStyle->setSizePolicy(sizePolicy1);

        horizontalLayout_3->addWidget(comboStyle);


        verticalLayout_2->addWidget(groupBox_4);

        groupBox_2 = new QGroupBox(DialogOptions);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        radioAskFirst = new QRadioButton(groupBox_2);
        radioAskFirst->setObjectName("radioAskFirst");
        radioAskFirst->setChecked(true);

        verticalLayout->addWidget(radioAskFirst);

        radioOverwrite = new QRadioButton(groupBox_2);
        radioOverwrite->setObjectName("radioOverwrite");

        verticalLayout->addWidget(radioOverwrite);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(DialogOptions);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_3 = new QVBoxLayout(groupBox_3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        checkCheckUpdates = new QCheckBox(groupBox_3);
        checkCheckUpdates->setObjectName("checkCheckUpdates");

        verticalLayout_3->addWidget(checkCheckUpdates);


        verticalLayout_2->addWidget(groupBox_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pushOk = new QPushButton(DialogOptions);
        pushOk->setObjectName("pushOk");

        horizontalLayout_2->addWidget(pushOk);

        pushCancel = new QPushButton(DialogOptions);
        pushCancel->setObjectName("pushCancel");

        horizontalLayout_2->addWidget(pushCancel);


        verticalLayout_2->addLayout(horizontalLayout_2);


        retranslateUi(DialogOptions);

        QMetaObject::connectSlotsByName(DialogOptions);
    } // setupUi

    void retranslateUi(QDialog *DialogOptions)
    {
        DialogOptions->setWindowTitle(QCoreApplication::translate("DialogOptions", "Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("DialogOptions", "Language", nullptr));
        label->setText(QCoreApplication::translate("DialogOptions", "Language:", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("DialogOptions", "Themes", nullptr));
        label_2->setText(QCoreApplication::translate("DialogOptions", "Style:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("DialogOptions", "Overwriting settings", nullptr));
        radioAskFirst->setText(QCoreApplication::translate("DialogOptions", "As&k first", nullptr));
        radioOverwrite->setText(QCoreApplication::translate("DialogOptions", "O&verwrite all existing images", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("DialogOptions", "Updates", nullptr));
        checkCheckUpdates->setText(QCoreApplication::translate("DialogOptions", "Checks for updates automatically", nullptr));
        pushOk->setText(QCoreApplication::translate("DialogOptions", "Ok", nullptr));
        pushCancel->setText(QCoreApplication::translate("DialogOptions", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogOptions: public Ui_DialogOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGOPTIONS_H
