/****************************************************************************
** Meta object code from reading C++ file 'mainwindowimpl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../converseen-0.15.2.7/src/mainwindowimpl.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindowimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MainWindowImplE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindowImpl::qt_create_metaobjectdata<qt_meta_tag_ZN14MainWindowImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindowImpl",
        "dropped",
        "",
        "fileNames",
        "directories",
        "openFiles",
        "addFiles",
        "openImportDirectoryDialog",
        "importIcoFile",
        "importPdfFile",
        "openMultipageFile",
        "fileName",
        "elabora",
        "setCurrentDirectory",
        "openOutDirectory",
        "removeItems",
        "removeAllItems",
        "setQuality",
        "selectGeometryUnit",
        "unit",
        "relativeSizeW",
        "relativeSizeH",
        "showImageInformations",
        "orig_w",
        "orig_h",
        "orig_dens_x",
        "orig_dens_y",
        "onItemSelection",
        "editSettings",
        "about",
        "enableRenameLine",
        "enableShowPreview",
        "enableProgressiveSpin",
        "showNewSizePreview",
        "onPushResetClick",
        "startConversion",
        "nextConversion",
        "conv_status",
        "overwriteDialog",
        "baseName",
        "stopProcess",
        "errorMessage",
        "err_status",
        "choseBackgroundColor",
        "openPaypalLink",
        "checkForUpdates",
        "manualCheckForUpdate",
        "updateAvailable",
        "isAvailable",
        "bugReport",
        "onlineHelp",
        "setRelativeSizeCheckboxes",
        "state",
        "setOverwriteStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dropped'
        QtMocHelpers::SlotData<void(QStringList, QStringList)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { QMetaType::QStringList, 4 },
        }}),
        // Slot 'openFiles'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addFiles'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openImportDirectoryDialog'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importIcoFile'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importPdfFile'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openMultipageFile'
        QtMocHelpers::SlotData<void(QString)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'elabora'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCurrentDirectory'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openOutDirectory'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeItems'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeAllItems'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setQuality'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectGeometryUnit'
        QtMocHelpers::SlotData<void(QString)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'relativeSizeW'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'relativeSizeH'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showImageInformations'
        QtMocHelpers::SlotData<void(int, int, double, double)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { QMetaType::Double, 25 }, { QMetaType::Double, 26 },
        }}),
        // Slot 'onItemSelection'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editSettings'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'about'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableRenameLine'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableShowPreview'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableProgressiveSpin'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showNewSizePreview'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPushResetClick'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startConversion'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'nextConversion'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 37 },
        }}),
        // Slot 'overwriteDialog'
        QtMocHelpers::SlotData<void(QString)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'stopProcess'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'errorMessage'
        QtMocHelpers::SlotData<void(QString)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'choseBackgroundColor'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openPaypalLink'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkForUpdates'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'manualCheckForUpdate'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAvailable'
        QtMocHelpers::SlotData<void(const bool &)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 48 },
        }}),
        // Slot 'bugReport'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onlineHelp'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setRelativeSizeCheckboxes'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'setOverwriteStatus'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindowImpl, qt_meta_tag_ZN14MainWindowImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindowImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainWindowImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainWindowImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MainWindowImplE_t>.metaTypes,
    nullptr
} };

void MainWindowImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindowImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 1: _t->openFiles(); break;
        case 2: _t->addFiles(); break;
        case 3: _t->openImportDirectoryDialog(); break;
        case 4: _t->importIcoFile(); break;
        case 5: _t->importPdfFile(); break;
        case 6: _t->openMultipageFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->elabora(); break;
        case 8: _t->setCurrentDirectory(); break;
        case 9: _t->openOutDirectory(); break;
        case 10: _t->removeItems(); break;
        case 11: _t->removeAllItems(); break;
        case 12: _t->setQuality(); break;
        case 13: _t->selectGeometryUnit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->relativeSizeW(); break;
        case 15: _t->relativeSizeH(); break;
        case 16: _t->showImageInformations((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 17: _t->onItemSelection(); break;
        case 18: _t->editSettings(); break;
        case 19: _t->about(); break;
        case 20: _t->enableRenameLine(); break;
        case 21: _t->enableShowPreview(); break;
        case 22: _t->enableProgressiveSpin(); break;
        case 23: _t->showNewSizePreview(); break;
        case 24: _t->onPushResetClick(); break;
        case 25: _t->startConversion(); break;
        case 26: _t->nextConversion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->overwriteDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->stopProcess(); break;
        case 29: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->choseBackgroundColor(); break;
        case 31: _t->openPaypalLink(); break;
        case 32: _t->checkForUpdates(); break;
        case 33: _t->manualCheckForUpdate(); break;
        case 34: _t->updateAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->bugReport(); break;
        case 36: _t->onlineHelp(); break;
        case 37: _t->setRelativeSizeCheckboxes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->setOverwriteStatus(); break;
        default: ;
        }
    }
}

const QMetaObject *MainWindowImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindowImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainWindowImplE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MainWindow"))
        return static_cast< Ui::MainWindow*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindowImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 39;
    }
    return _id;
}
QT_WARNING_POP
